@@ -1,8 +1,15 @@
+from ipaddress import ip_address
+
 from django.db.models import Q
-from django_netjsonconfig.controller.generics import (BaseDeviceChecksumView, BaseDeviceDownloadConfigView,
-                                                      BaseDeviceRegisterView, BaseDeviceReportStatusView,
-                                                      BaseDeviceUpdateInfoView, BaseVpnChecksumView,
-                                                      BaseVpnDownloadConfigView)
+from django_netjsonconfig.controller.generics import (
+    BaseDeviceChecksumView,
+    BaseDeviceDownloadConfigView,
+    BaseDeviceRegisterView,
+    BaseDeviceReportStatusView,
+    BaseDeviceUpdateInfoView,
+    BaseVpnChecksumView,
+    BaseVpnDownloadConfigView,
+)
 from django_netjsonconfig.utils import invalid_response
 
 from ..models import Device, OrganizationConfigSettings, Vpn
@@ -12,12 +19,37 @@ class ActiveOrgMixin(object):
     """
     adds check to organization.is_active to ``get_object`` method
     """
+
     def get_object(self, *args, **kwargs):
         kwargs['organization__is_active'] = True
         return super().get_object(*args, **kwargs)
 
 
-class DeviceChecksumView(ActiveOrgMixin, BaseDeviceChecksumView):
+class UpdateLastIpMixin(object):
+    def update_last_ip(self, device, request):
+        result = super().update_last_ip(device, request)
+        if result:
+            # avoid that any other device in the
+            # same org stays with the same management_ip
+            # This can happen when management interfaces are using DHCP
+            # and they get a new address which was previously used by another
+            # device that may now be offline, without this fix, we will end up
+            # with two devices having the same management_ip, which will
+            # cause OpenWISP to be confused
+            Device.objects.filter(
+                organization=device.organization, management_ip=device.management_ip,
+            ).exclude(pk=device.pk).update(management_ip='')
+            # in the case of last_ip, we take a different approach,
+            # because it may be a public IP. If it's a public IP we will
+            # allow it to be duplicated
+            if ip_address(device.last_ip).is_private:
+                Device.objects.filter(
+                    organization=device.organization, last_ip=device.last_ip,
+                ).exclude(pk=device.pk).update(last_ip='')
+        return result
+
+
+class DeviceChecksumView(UpdateLastIpMixin, ActiveOrgMixin, BaseDeviceChecksumView):
     model = Device
 
 
@@ -33,7 +65,7 @@ class DeviceReportStatusView(ActiveOrgMixin, BaseDeviceReportStatusView):
     model = Device
 
 
-class DeviceRegisterView(BaseDeviceRegisterView):
+class DeviceRegisterView(UpdateLastIpMixin, BaseDeviceRegisterView):
     model = Device
 
     def forbidden(self, request):
@@ -44,10 +76,9 @@ class DeviceRegisterView(BaseDeviceRegisterView):
         """
         try:
             secret = request.POST.get('secret')
-            org_settings = OrganizationConfigSettings.objects \
-                                                     .select_related('organization') \
-                                                     .get(shared_secret=secret,
-                                                          organization__is_active=True)
+            org_settings = OrganizationConfigSettings.objects.select_related(
+                'organization'
+            ).get(shared_secret=secret, organization__is_active=True)
         except OrganizationConfigSettings.DoesNotExist:
             return invalid_response(request, 'error: unrecognized secret', status=403)
         if not org_settings.registration_enabled:
@@ -65,8 +96,7 @@ class DeviceRegisterView(BaseDeviceRegisterView):
     def get_template_queryset(self, config):
         queryset = super().get_template_queryset(config)
         # filter templates of the same organization or shared templates
-        return queryset.filter(Q(organization=self.organization) |
-                               Q(organization=None))
+        return queryset.filter(Q(organization=self.organization) | Q(organization=None))
 
 
 class VpnChecksumView(BaseVpnChecksumView):
