@@ -7,8 +7,9 @@ from ..models import Config, Device, Template
 from . import CreateConfigTemplateMixin, TestVpnX509Mixin
 
 
-class TestConfig(CreateConfigTemplateMixin, TestVpnX509Mixin,
-                 TestOrganizationMixin, TestCase):
+class TestConfig(
+    CreateConfigTemplateMixin, TestVpnX509Mixin, TestOrganizationMixin, TestCase
+):
     config_model = Config
     device_model = Device
     template_model = Template
