@@ -16,6 +16,7 @@ from openwisp_utils.base import TimeStampedEditableModel
 
 from ..config.models import Device
 from . import settings as app_settings
+from .signals import is_working_changed
 
 logger = logging.getLogger(__name__)
 
@@ -24,8 +25,18 @@ class ConnectorMixin(object):
     _connector_field = 'connector'
 
     def clean(self):
+        # Validate the connector field here to avoid ImportError in case that
+        # it is not valid (eg. it is an empty string because the user has forgotten
+        # to pick up one from the choices). The field value is validated in a later
+        # stage anyways. We are returning {} to avoid showing a duplicate error
+        # message for the field
+        if not self._get_connector():
+            raise ValidationError({})
         self._validate_connector_schema()
 
+    def _get_connector(self):
+        return getattr(self, self._connector_field)
+
     def _validate_connector_schema(self):
         try:
             self.connector_class.validate(self.get_params())
@@ -40,33 +51,44 @@ class ConnectorMixin(object):
 
     @cached_property
     def connector_class(self):
-        return import_string(getattr(self, self._connector_field))
+        connector = self._get_connector()
+        return import_string(connector)
 
     @cached_property
     def connector_instance(self):
-        return self.connector_class(params=self.get_params(),
-                                    addresses=self.get_addresses())
+        return self.connector_class(
+            params=self.get_params(), addresses=self.get_addresses()
+        )
 
 
 class Credentials(ConnectorMixin, ShareableOrgMixin, BaseModel):
     """
     Credentials for access
     """
-    connector = models.CharField(_('connection type'),
-                                 choices=app_settings.CONNECTORS,
-                                 max_length=128,
-                                 db_index=True)
-    params = JSONField(_('parameters'),
-                       default=dict,
-                       help_text=_('global connection parameters'),
-                       load_kwargs={'object_pairs_hook': collections.OrderedDict},
-                       dump_kwargs={'indent': 4})
-    auto_add = models.BooleanField(_('auto add'),
-                                   default=False,
-                                   help_text=_('automatically add these credentials '
-                                               'to the devices of this organization; '
-                                               'if no organization is specified will '
-                                               'be added to all the new devices'))
+
+    connector = models.CharField(
+        _('connection type'),
+        choices=app_settings.CONNECTORS,
+        max_length=128,
+        db_index=True,
+    )
+    params = JSONField(
+        _('parameters'),
+        default=dict,
+        help_text=_('global connection parameters'),
+        load_kwargs={'object_pairs_hook': collections.OrderedDict},
+        dump_kwargs={'indent': 4},
+    )
+    auto_add = models.BooleanField(
+        _('auto add'),
+        default=False,
+        help_text=_(
+            'automatically add these credentials '
+            'to the devices of this organization; '
+            'if no organization is specified will '
+            'be added to all the new devices'
+        ),
+    )
 
     class Meta:
         verbose_name = _('Access credentials')
@@ -86,16 +108,14 @@ class Credentials(ConnectorMixin, ShareableOrgMixin, BaseModel):
         """
         if not self.auto_add:
             return
-        devices = Device.objects.all()
+        devices = Device.objects.exclude(config=None)
         org = self.organization
         if org:
             devices = devices.filter(organization=org)
         # exclude devices which have been already added
         devices = devices.exclude(deviceconnection__credentials=self)
         for device in devices:
-            conn = DeviceConnection(device=device,
-                                    credentials=self,
-                                    enabled=True)
+            conn = DeviceConnection(device=device, credentials=self, enabled=True)
             conn.full_clean()
             conn.save()
 
@@ -117,14 +137,12 @@ class Credentials(ConnectorMixin, ShareableOrgMixin, BaseModel):
         #   - belong to the same organization of the device
         #     OR
         #     belong to no organization (hence are shared)
-        conditions = (models.Q(organization=device.organization) |
-                      models.Q(organization=None))
-        credentials = cls.objects.filter(conditions) \
-                                 .filter(auto_add=True)
+        conditions = models.Q(organization=device.organization) | models.Q(
+            organization=None
+        )
+        credentials = cls.objects.filter(conditions).filter(auto_add=True)
         for cred in credentials:
-            conn = DeviceConnection(device=device,
-                                    credentials=cred,
-                                    enabled=True)
+            conn = DeviceConnection(device=device, credentials=cred, enabled=True)
             conn.full_clean()
             conn.save()
 
@@ -133,53 +151,77 @@ class DeviceConnection(ConnectorMixin, TimeStampedEditableModel):
     _connector_field = 'update_strategy'
     device = models.ForeignKey('config.Device', on_delete=models.CASCADE)
     credentials = models.ForeignKey(Credentials, on_delete=models.CASCADE)
-    update_strategy = models.CharField(_('update strategy'),
-                                       help_text=_('leave blank to determine automatically'),
-                                       choices=app_settings.UPDATE_STRATEGIES,
-                                       max_length=128,
-                                       blank=True,
-                                       db_index=True)
+    update_strategy = models.CharField(
+        _('update strategy'),
+        help_text=_('leave blank to determine automatically'),
+        choices=app_settings.UPDATE_STRATEGIES,
+        max_length=128,
+        blank=True,
+        db_index=True,
+    )
     enabled = models.BooleanField(default=True, db_index=True)
-    params = JSONField(_('parameters'),
-                       default=dict,
-                       blank=True,
-                       help_text=_('local connection parameters (will override '
-                                   'the global parameters if specified)'),
-                       load_kwargs={'object_pairs_hook': collections.OrderedDict},
-                       dump_kwargs={'indent': 4})
+    params = JSONField(
+        _('parameters'),
+        default=dict,
+        blank=True,
+        help_text=_(
+            'local connection parameters (will override '
+            'the global parameters if specified)'
+        ),
+        load_kwargs={'object_pairs_hook': collections.OrderedDict},
+        dump_kwargs={'indent': 4},
+    )
     # usability improvements
     is_working = models.NullBooleanField(default=None)
-    failure_reason = models.CharField(_('reason of failure'),
-                                      max_length=128,
-                                      blank=True)
+    failure_reason = models.CharField(
+        _('reason of failure'), max_length=128, blank=True
+    )
     last_attempt = models.DateTimeField(blank=True, null=True)
 
     class Meta:
         verbose_name = _('Device connection')
         verbose_name_plural = _('Device connections')
 
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self._initial_is_working = self.is_working
+
     def clean(self):
         cred_org = self.credentials.organization
         if cred_org and cred_org != self.device.organization:
-            raise ValidationError({
-                'credentials': _('The organization of these credentials doesn\'t '
-                                 'match the organization of the device')
-            })
-        if not self.update_strategy and hasattr(self.device, 'config'):
+            raise ValidationError(
+                {
+                    'credentials': _(
+                        'The organization of these credentials doesn\'t '
+                        'match the organization of the device'
+                    )
+                }
+            )
+        if not self.update_strategy and self.device._has_config():
             try:
-                self.update_strategy = app_settings.CONFIG_UPDATE_MAPPING[self.device.config.backend]
+                self.update_strategy = app_settings.CONFIG_UPDATE_MAPPING[
+                    self.device.config.backend
+                ]
             except KeyError as e:
-                raise ValidationError({
-                    'update_stragy': _('could not determine update strategy '
-                                       ' automatically, exception: {0}'.format(e))
-                })
+                raise ValidationError(
+                    {
+                        'update_stragy': _(
+                            'could not determine update strategy '
+                            ' automatically, exception: {0}'.format(e)
+                        )
+                    }
+                )
         elif not self.update_strategy:
-            raise ValidationError({
-                'update_strategy': _('the update strategy can be determined automatically '
-                                     'only if the device has a configuration specified, '
-                                     'because it is inferred from the configuration backend. '
-                                     'Please select the update strategy manually.')
-            })
+            raise ValidationError(
+                {
+                    'update_strategy': _(
+                        'the update strategy can be determined automatically '
+                        'only if the device has a configuration specified, '
+                        'because it is inferred from the configuration backend. '
+                        'Please select the update strategy manually.'
+                    )
+                }
+            )
         self._validate_connector_schema()
 
     def get_addresses(self):
@@ -190,7 +232,7 @@ class DeviceConnection(ConnectorMixin, TimeStampedEditableModel):
         address_list = []
         if self.device.management_ip:
             address_list.append(self.device.management_ip)
-        if self.device.last_ip:
+        if self.device.last_ip and self.device.last_ip != self.device.management_ip:
             address_list.append(self.device.last_ip)
         return address_list
 
@@ -199,6 +241,9 @@ class DeviceConnection(ConnectorMixin, TimeStampedEditableModel):
         params.update(self.params)
         return params
 
+    def set_connector(self, connector):
+        self.connector_instance = connector
+
     def connect(self):
         try:
             self.connector_instance.connect()
@@ -226,3 +271,18 @@ class DeviceConnection(ConnectorMixin, TimeStampedEditableModel):
             else:
                 self.device.config.set_status_applied()
                 self.disconnect()
+
+    def save(self, *args, **kwargs):
+        super().save(*args, **kwargs)
+        if self.is_working != self._initial_is_working:
+            self.send_is_working_changed_signal()
+        self._initial_is_working = self.is_working
+
+    def send_is_working_changed_signal(self):
+        is_working_changed.send(
+            sender=self.__class__,
+            is_working=self.is_working,
+            old_is_working=self._initial_is_working,
+            failure_reason=self.failure_reason,
+            instance=self,
+        )
