@@ -1,6 +1,7 @@
 import os
 
 from django.conf import settings
+from mockssh import Server
 from openwisp_controller.config.models import Config, Device
 from openwisp_controller.config.tests import CreateConfigTemplateMixin
 
@@ -10,6 +11,21 @@ from .. import settings as app_settings
 from ..models import Credentials, DeviceConnection
 
 
+class SshServer(Server):
+    def _run(self, *args, **kwargs):
+        """
+        Hides "Bad file descriptor" system issue which
+        does not affect the effectivness of the tests
+        """
+        try:
+            return super()._run(*args, **kwargs)
+        except OSError as e:
+            if str(e) == '[Errno 9] Bad file descriptor':
+                pass
+            else:
+                raise e
+
+
 class CreateConnectionsMixin(CreateConfigTemplateMixin, TestOrganizationMixin):
     device_model = Device
     config_model = Config
@@ -29,18 +45,28 @@ class CreateConnectionsMixin(CreateConfigTemplateMixin, TestOrganizationMixin):
 
     def _create_device(self, *args, **kwargs):
         if 'last_ip' not in kwargs and 'management_ip' not in kwargs:
-            kwargs.update({
-                'last_ip': self.ssh_server.host,
-                'management_ip': self.ssh_server.host,
-            })
+            kwargs.update(
+                {
+                    'last_ip': self.ssh_server.host,
+                    'management_ip': self.ssh_server.host,
+                }
+            )
         return super()._create_device(*args, **kwargs)
 
+    def _get_credentials(self, **kwargs):
+        opts = {"name": "Test credentials"}
+        opts.update(**kwargs)
+        try:
+            return Credentials.objects.get(**opts)
+        except Credentials.DoesNotExist:
+            return self._create_credentials(**opts)
+
     def _create_credentials(self, **kwargs):
-        opts = dict(name='Test credentials',
-                    connector=app_settings.CONNECTORS[0][0],
-                    params={'username': 'root',
-                            'password': 'password',
-                            'port': 22})
+        opts = dict(
+            name='Test credentials',
+            connector=app_settings.CONNECTORS[0][0],
+            params={'username': 'root', 'password': 'password', 'port': 22},
+        )
         opts.update(kwargs)
         if 'organization' not in opts:
             opts['organization'] = self._create_org()
@@ -50,16 +76,19 @@ class CreateConnectionsMixin(CreateConfigTemplateMixin, TestOrganizationMixin):
         return c
 
     def _create_credentials_with_key(self, username='root', port=22, **kwargs):
-        opts = dict(name='Test SSH Key',
-                    params={'username': username,
-                            'key': self._TEST_RSA_PRIVATE_KEY_VALUE,
-                            'port': port})
+        opts = dict(
+            name='Test SSH Key',
+            params={
+                'username': username,
+                'key': self._TEST_RSA_PRIVATE_KEY_VALUE,
+                'port': port,
+            },
+        )
         opts.update(kwargs)
         return self._create_credentials(**opts)
 
     def _create_device_connection(self, **kwargs):
-        opts = dict(enabled=True,
-                    params={})
+        opts = dict(enabled=True, params={})
         opts.update(kwargs)
         if 'credentials' not in opts:
             cred_opts = {}
