@@ -18,7 +18,7 @@ class TestAdmin(TestAdminMixin, CreateConnectionsMixin, TestCase):
         {'codename__endswith': 'template'},
         {'codename__endswith': 'connection'},
         {'codename__endswith': 'credentials'},
-        {'codename__endswith': 'device_connection'}
+        {'codename__endswith': 'device_connection'},
     ]
     _device_params = TestConfigAdmin._device_params.copy()
 
@@ -38,10 +38,18 @@ class TestAdmin(TestAdminMixin, CreateConnectionsMixin, TestCase):
         dc1 = self._create_device_connection(credentials=cred1)
         dc2 = self._create_device_connection(credentials=cred2)
         dc3 = self._create_device_connection(credentials=cred3)
-        data = dict(cred1=cred1, cred2=cred2, cred3_inactive=cred3,
-                    dc1=dc1, dc2=dc2, dc3_inactive=dc3,
-                    org1=org1, org2=org2, inactive=inactive,
-                    operator=operator)
+        data = dict(
+            cred1=cred1,
+            cred2=cred2,
+            cred3_inactive=cred3,
+            dc1=dc1,
+            dc2=dc2,
+            dc3_inactive=dc3,
+            org1=org1,
+            org2=org2,
+            inactive=inactive,
+            operator=operator,
+        )
         return data
 
     def test_credentials_queryset(self):
@@ -49,8 +57,7 @@ class TestAdmin(TestAdminMixin, CreateConnectionsMixin, TestCase):
         self._test_multitenant_admin(
             url=reverse('admin:connection_credentials_changelist'),
             visible=[data['cred1'].name, data['org1'].name],
-            hidden=[data['cred2'].name, data['org2'].name,
-                    data['cred3_inactive'].name]
+            hidden=[data['cred2'].name, data['org2'].name, data['cred3_inactive'].name],
         )
 
     def test_credentials_organization_fk_queryset(self):
@@ -59,7 +66,7 @@ class TestAdmin(TestAdminMixin, CreateConnectionsMixin, TestCase):
             url=reverse('admin:connection_credentials_add'),
             visible=[data['org1'].name],
             hidden=[data['org2'].name, data['inactive']],
-            select_widget=True
+            select_widget=True,
         )
 
     def test_connection_queryset(self):
@@ -67,15 +74,18 @@ class TestAdmin(TestAdminMixin, CreateConnectionsMixin, TestCase):
         self._test_multitenant_admin(
             url=reverse('admin:connection_credentials_changelist'),
             visible=[data['dc1'].credentials.name, data['org1'].name],
-            hidden=[data['dc2'].credentials.name, data['org2'].name,
-                    data['dc3_inactive'].credentials.name]
+            hidden=[
+                data['dc2'].credentials.name,
+                data['org2'].name,
+                data['dc3_inactive'].credentials.name,
+            ],
         )
 
     def test_connection_credentials_fk_queryset(self):
         data = self._create_multitenancy_test_env()
         self._test_multitenant_admin(
             url=reverse('admin:config_device_add'),
-            visible=[str(data['cred1'].name) + str(" (SSH)")],
-            hidden=[str(data['cred2'].name) + str(" (SSH)"), data['cred3_inactive']],
-            select_widget=True
+            visible=[str(data['cred1'].name) + str(' (SSH)')],
+            hidden=[str(data['cred2'].name) + str(' (SSH)'), data['cred3_inactive']],
+            select_widget=True,
         )
