@@ -28,13 +28,9 @@ def assign_permissions_to_groups(apps, schema_editor):
 
 
 class Migration(migrations.Migration):
-    dependencies = [
-        ('openwisp_users', '0004_default_groups'),
-        ('geo', '0001_initial')
-    ]
+    dependencies = [('openwisp_users', '0004_default_groups'), ('geo', '0001_initial')]
     operations = [
         migrations.RunPython(
-            assign_permissions_to_groups,
-            reverse_code=migrations.RunPython.noop
+            assign_permissions_to_groups, reverse_code=migrations.RunPython.noop
         )
     ]
