@@ -20,13 +20,15 @@ def assign_permissions_to_groups(apps, schema_editor):
 
     for model_name in operators_read_only_admins_manage:
         try:
-            permission = Permission.objects.get(codename="view_{}".format(model_name))
+            permission = Permission.objects.get(codename='view_{}'.format(model_name))
             operator.permissions.add(permission.pk)
         except Permission.DoesNotExist:
             pass
         for operation in manage_operations:
             admin.permissions.add(
-                Permission.objects.get(codename="{}_{}".format(operation, model_name)).pk
+                Permission.objects.get(
+                    codename='{}_{}'.format(operation, model_name)
+                ).pk
             )
 
 
@@ -36,8 +38,7 @@ class Migration(migrations.Migration):
         ('pki', '0006_add_x509_passphrase_field'),
     ]
     operations = [
-            migrations.RunPython(
-                assign_permissions_to_groups,
-                reverse_code=migrations.RunPython.noop
-            )
+        migrations.RunPython(
+            assign_permissions_to_groups, reverse_code=migrations.RunPython.noop
+        )
     ]
